@@ -740,6 +740,11 @@ extern char *TMH_helper_sms;
  */
 extern char *TMH_allowed_payment_targets;
 
+/**
+ * Default persona to use for new browsers.
+ */
+extern char *TMH_default_persona;
+
 /**
  * Regular expression further restricting payment target types.
  * Can be NULL/empty for no restrictions.
@@ -796,6 +801,12 @@ extern struct GNUNET_TIME_Relative TMH_legal_expiration;
  */
 extern struct GNUNET_TIME_Relative TMH_default_wire_transfer_delay;
 
+/**
+ * Default rounding interval to be applied to new instances.
+ */
+extern enum GNUNET_TIME_RounderInterval
+  TMH_default_wire_transfer_rounding_interval;
+
 /**
  * Default payment delay for new instances.
  */
