@@ -43,7 +43,7 @@
  * #MERCHANT_PROTOCOL_CURRENT and #MERCHANT_PROTOCOL_AGE in
  * merchant_api_get_config.c!
  */
-#define MERCHANT_PROTOCOL_VERSION "22:0:10"
+#define MERCHANT_PROTOCOL_VERSION "23:1:11"
 
 
 /**
@@ -122,6 +122,8 @@ MH_handler_config (const struct TMH_RequestHandler *rh,
                                TMH_currency),
       GNUNET_JSON_pack_string ("payment_target_types",
                                TMH_allowed_payment_targets),
+      GNUNET_JSON_pack_string ("default_persona",
+                               TMH_default_persona),
       GNUNET_JSON_pack_allow_null (
         GNUNET_JSON_pack_string ("payment_target_regex",
                                  TMH_payment_target_regex)),
