@@ -274,5 +274,17 @@ TMH_exchange_accounts_by_method (
   const struct TALER_MasterPublicKeyP *master_pub,
   const char *wire_method);
 
+/**
+ * Check validity of login @a token for the given @a instance_id.
+ *
+ * @param token the login token given in the request
+ * @param instance_id the instance the login is to be checked against
+ * @param[out] as set to scope of the token if it is valid
+ * @return TALER_EC_NONE on success
+ */
+enum TALER_ErrorCode
+TMH_check_token (const char *token,
+                 const char *instance_id,
+                 enum TMH_AuthScope *as);
 
 #endif
