@@ -666,23 +666,26 @@ TMH_post_orders_ID_refund (const struct TMH_RequestHandler *rh,
                                        NULL);
   }
 
+  qs = TMH_db->lookup_refunds_detailed (TMH_db->cls,
+                                        hc->instance->settings.id,
+                                        &prd->h_contract_terms,
+                                        &process_refunds_cb,
+                                        prd);
+  if (0 > qs)
   {
-    GNUNET_assert (GNUNET_OK ==
-                   TALER_amount_set_zero (TMH_currency,
-                                          &prd->refund_amount));
-    qs = TMH_db->lookup_refunds_detailed (TMH_db->cls,
-                                          hc->instance->settings.id,
-                                          &prd->h_contract_terms,
-                                          &process_refunds_cb,
-                                          prd);
-    if (0 > qs)
-    {
-      GNUNET_break (0);
-      return TALER_MHD_reply_with_error (connection,
-                                         MHD_HTTP_INTERNAL_SERVER_ERROR,
-                                         TALER_EC_GENERIC_DB_FETCH_FAILED,
-                                         "detailed refunds");
-    }
+    GNUNET_break (0);
+    return TALER_MHD_reply_with_error (connection,
+                                       MHD_HTTP_INTERNAL_SERVER_ERROR,
+                                       TALER_EC_GENERIC_DB_FETCH_FAILED,
+                                       "detailed refunds");
+  }
+  if (GNUNET_DB_STATUS_SUCCESS_NO_RESULTS == qs)
+  {
+    GNUNET_break (0);
+    return TALER_MHD_reply_with_error (connection,
+                                       MHD_HTTP_INTERNAL_SERVER_ERROR,
+                                       TALER_EC_GENERIC_DB_FETCH_FAILED,
+                                       "no coins found that could be refunded");
   }
 
   /* Now launch exchange interactions, unless we already have the
@@ -711,6 +714,14 @@ TMH_post_orders_ID_refund (const struct TMH_RequestHandler *rh,
                                               false,
                                               &exchange_found_cb,
                                               cr);
+        if (NULL == cr->fo)
+        {
+          GNUNET_break (0);
+          return TALER_MHD_reply_with_error (connection,
+                                             MHD_HTTP_INTERNAL_SERVER_ERROR,
+                                             TALER_EC_MERCHANT_GENERIC_EXCHANGE_UNTRUSTED,
+                                             cr->exchange_url);
+        }
       }
       break;
     case GNUNET_DB_STATUS_SUCCESS_ONE_RESULT:
