@@ -684,6 +684,40 @@ ekr_expand_response (struct ExchangeKycRequest *ekr)
 }
 
 
+/**
+ * We are done with asynchronous processing, generate the
+ * response for the @e kc.
+ *
+ * @param[in,out] kc KYC context to respond for
+ */
+static void
+kc_respond (struct KycContext *kc)
+{
+  if ( (! kc->return_immediately) &&
+       (! GNUNET_TIME_absolute_is_past (kc->timeout)) )
+  {
+    if (GNUNET_NO == kc->suspended)
+    {
+      GNUNET_log (GNUNET_ERROR_TYPE_INFO,
+                  "Suspending: long poll target %d not reached\n",
+                  kc->lpt);
+      MHD_suspend_connection (kc->connection);
+      kc->suspended = GNUNET_YES;
+    }
+    else
+    {
+      GNUNET_log (GNUNET_ERROR_TYPE_INFO,
+                  "Remaining suspended: long poll target %d not reached\n",
+                  kc->lpt);
+    }
+    return;
+  }
+  /* All exchange requests done, create final
+     big response from cumulated replies */
+  resume_kyc_with_response (kc);
+}
+
+
 /**
  * We are done with the KYC request @a ekr.  Remove it from the work list and
  * check if we are done overall.
@@ -709,29 +743,7 @@ ekr_finished (struct ExchangeKycRequest *ekr)
 
   if (NULL != kc->exchange_pending_head)
     return; /* wait for more */
-
-  if ( (! kc->return_immediately) &&
-       (! GNUNET_TIME_absolute_is_past (kc->timeout)) )
-  {
-    if (GNUNET_NO == kc->suspended)
-    {
-      GNUNET_log (GNUNET_ERROR_TYPE_INFO,
-                  "Suspending: long poll target %d not reached\n",
-                  kc->lpt);
-      MHD_suspend_connection (kc->connection);
-      kc->suspended = GNUNET_YES;
-    }
-    else
-    {
-      GNUNET_log (GNUNET_ERROR_TYPE_INFO,
-                  "Remaining suspended: long poll target %d not reached\n",
-                  kc->lpt);
-    }
-    return;
-  }
-  /* All exchange requests done, create final
-     big response from cumulated replies */
-  resume_kyc_with_response (kc);
+  kc_respond (kc);
 }
 
 
@@ -878,6 +890,72 @@ kyc_with_exchange (void *cls,
 }
 
 
+/**
+ * Closure for add_unreachable_status().
+ */
+struct UnreachableContext
+{
+  /**
+   * Where we are building the response.
+   */
+  struct KycContext *kc;
+
+  /**
+   * Pointer to our account hash.
+   */
+  const struct TALER_MerchantWireHashP *h_wire;
+
+  /**
+   * Bank account for which we have no status from any exchange.
+   */
+  struct TALER_FullPayto payto_uri;
+
+};
+
+/**
+ * Add all trusted exchanges with "unknown" status for the
+ * bank account given in the context.
+ *
+ * @param cls a `struct UnreachableContext`
+ * @param url base URL of the exchange
+ * @param exchange internal handle for the exchange
+ */
+static void
+add_unreachable_status (void *cls,
+                        const char *url,
+                        const struct TMH_Exchange *exchange)
+{
+  struct UnreachableContext *uc = cls;
+  struct KycContext *kc = uc->kc;
+
+  GNUNET_assert (
+    0 ==
+    json_array_append_new (
+      kc->kycs_data,
+      GNUNET_JSON_PACK (
+        TALER_JSON_pack_full_payto (
+          "payto_uri",
+          uc->payto_uri),
+        GNUNET_JSON_pack_data_auto (
+          "h_wire",
+          uc->h_wire),
+        GNUNET_JSON_pack_string (
+          "status",
+          "exchange-unreachable"),
+        GNUNET_JSON_pack_string (
+          "exchange_url",
+          url),
+        GNUNET_JSON_pack_bool ("no_keys",
+                               true),
+        GNUNET_JSON_pack_bool ("auth_conflict",
+                               false),
+        GNUNET_JSON_pack_uint64 ("exchange_http_status",
+                                 0)
+        )));
+
+}
+
+
 /**
  * Function called from account_kyc_get_status() with KYC status information
  * for this merchant.
@@ -911,6 +989,21 @@ kyc_status_cb (
   struct KycContext *kc = cls;
   struct ExchangeKycRequest *ekr;
 
+  if (NULL == exchange_url)
+  {
+    struct UnreachableContext uc = {
+      .kc = kc,
+      .h_wire = h_wire,
+      .payto_uri = payto_uri
+    };
+
+    GNUNET_log (GNUNET_ERROR_TYPE_INFO,
+                "Account has unknown KYC status for all exchanges.\n");
+    TMH_exchange_get_trusted (&add_unreachable_status,
+                              &uc);
+    kc_respond (kc);
+    return;
+  }
   if (! TMH_EXCHANGES_check_trusted (exchange_url))
   {
     GNUNET_log (GNUNET_ERROR_TYPE_INFO,
