@@ -112,6 +112,9 @@ get_instances_ID (struct TMH_MerchantInstance *mi,
                                mi->settings.default_pay_delay),
     GNUNET_JSON_pack_time_rel ("default_refund_delay",
                                mi->settings.default_refund_delay),
+    GNUNET_JSON_pack_time_rounder_interval (
+      "default_wire_transfer_rounding_interval",
+      mi->settings.default_wire_transfer_rounding_interval),
     GNUNET_JSON_pack_object_steal ("auth",
                                    auth));
 }
