@@ -1,6 +1,6 @@
 /*
   This file is part of TALER
-  (C) 2019-2021 Taler Systems SA
+  (C) 2019--2025 Taler Systems SA
 
   TALER is free software; you can redistribute it and/or modify it under the
   terms of the GNU Affero General Public License as published by the Free Software
@@ -84,6 +84,11 @@ struct TMH_PendingOrder
    */
   const char *instance_id;
 
+  /**
+   * Alias of @a of.summary_filter, but with memory to be released (owner).
+   */
+  char *summary_filter;
+
   /**
    * The result after adding the orders (#TALER_EC_NONE for okay, anything else for an error).
    */
@@ -221,6 +226,7 @@ cleanup (void *ctx)
     GNUNET_assert (po ==
                    GNUNET_CONTAINER_heap_remove_node (po->hn));
   json_decref (po->pa);
+  GNUNET_free (po->summary_filter);
   GNUNET_free (po);
 }
 
@@ -681,6 +687,42 @@ TMH_notify_order_change (struct TMH_MerchantInstance *mi,
 }
 
 
+/**
+ * Transforms an (untrusted) input filter into a Postgresql LIKE filter.
+ * Escapes "%" and "_" in the @a input and adds "%" at the beginning
+ * and the end to turn the @a input into a suitable Postgresql argument.
+ *
+ * @param input text to turn into a substring match expression, or NULL
+ * @return NULL if @a input was NULL, otherwise transformed @a input
+ */
+static char *
+tr (const char *input)
+{
+  char *out;
+  size_t slen;
+  size_t wpos;
+
+  if (NULL == input)
+    return NULL;
+  slen = strlen (input);
+  out = GNUNET_malloc (slen * 2 + 3);
+  wpos = 0;
+  out[wpos++] = '%';
+  for (size_t i = 0; i<slen; i++)
+  {
+    char c = input[i];
+
+    if ( (c == '%') ||
+         (c == '_') )
+      out[wpos++] = '\\';
+    out[wpos++] = c;
+  }
+  out[wpos++] = '%';
+  GNUNET_assert (wpos < slen * 2 + 3);
+  return out;
+}
+
+
 /**
  * Handle a GET "/orders" request.
  *
@@ -838,6 +880,10 @@ TMH_private_get_orders (const struct TMH_RequestHandler *rh,
                                        TALER_EC_GENERIC_PARAMETER_MALFORMED,
                                        "offset");
   }
+  po->summary_filter = tr (MHD_lookup_connection_value (connection,
+                                                        MHD_GET_ARGUMENT_KIND,
+                                                        "summary_filter"));
+  po->of.summary_filter = po->summary_filter; /* just an (read-only) alias! */
   po->of.session_id
     = MHD_lookup_connection_value (connection,
                                    MHD_GET_ARGUMENT_KIND,
