@@ -82,10 +82,12 @@ TMH_private_get_products_ID (
     ret = TALER_MHD_REPLY_JSON_PACK (
       connection,
       MHD_HTTP_OK,
+      GNUNET_JSON_pack_string ("product_name",
+                               pd.product_name),
       GNUNET_JSON_pack_string ("description",
                                pd.description),
-      GNUNET_JSON_pack_object_steal ("description_i18n",
-                                     pd.description_i18n),
+      GNUNET_JSON_pack_object_incref ("description_i18n",
+                                      pd.description_i18n),
       GNUNET_JSON_pack_string ("unit",
                                pd.unit),
       GNUNET_JSON_pack_array_steal ("categories",
@@ -96,8 +98,8 @@ TMH_private_get_products_ID (
         GNUNET_JSON_pack_string ("image",
                                  pd.image)),
       GNUNET_JSON_pack_allow_null (
-        GNUNET_JSON_pack_array_steal ("taxes",
-                                      pd.taxes)),
+        GNUNET_JSON_pack_array_incref ("taxes",
+                                       pd.taxes)),
       GNUNET_JSON_pack_int64 ("total_stock",
                               (INT64_MAX == pd.total_stock)
                               ? -1LL
@@ -107,16 +109,14 @@ TMH_private_get_products_ID (
       GNUNET_JSON_pack_uint64 ("total_lost",
                                pd.total_lost),
       GNUNET_JSON_pack_allow_null (
-        GNUNET_JSON_pack_object_steal ("address",
-                                       pd.address)),
+        GNUNET_JSON_pack_object_incref ("address",
+                                        pd.address)),
       GNUNET_JSON_pack_allow_null (
         GNUNET_JSON_pack_timestamp ("next_restock",
                                     (pd.next_restock))),
       GNUNET_JSON_pack_uint64 ("minimum_age",
                                pd.minimum_age));
-    GNUNET_free (pd.description);
-    GNUNET_free (pd.image);
-    GNUNET_free (pd.unit);
+    TALER_MERCHANTDB_product_details_free (&pd);
     return ret;
   }
 }
