@@ -95,10 +95,6 @@ patch_instances_ID (struct TMH_MerchantInstance *mi,
                            &is.jurisdiction),
     GNUNET_JSON_spec_bool ("use_stefan",
                            &is.use_stefan),
-    GNUNET_JSON_spec_mark_optional (
-      GNUNET_JSON_spec_relative_time ("default_wire_transfer_delay",
-                                      &is.default_wire_transfer_delay),
-      &no_transfer_delay),
     GNUNET_JSON_spec_mark_optional (
       GNUNET_JSON_spec_relative_time ("default_pay_delay",
                                       &is.default_pay_delay),
@@ -107,6 +103,15 @@ patch_instances_ID (struct TMH_MerchantInstance *mi,
       GNUNET_JSON_spec_relative_time ("default_refund_delay",
                                       &is.default_refund_delay),
       &no_refund_delay),
+    GNUNET_JSON_spec_mark_optional (
+      GNUNET_JSON_spec_relative_time ("default_wire_transfer_delay",
+                                      &is.default_wire_transfer_delay),
+      &no_transfer_delay),
+    GNUNET_JSON_spec_mark_optional (
+      GNUNET_JSON_spec_time_rounder_interval (
+        "default_wire_transfer_rounding_interval",
+        &is.default_wire_transfer_rounding_interval),
+      NULL),
     GNUNET_JSON_spec_end ()
   };
   enum GNUNET_DB_QueryStatus qs;
@@ -162,6 +167,33 @@ patch_instances_ID (struct TMH_MerchantInstance *mi,
     is.default_pay_delay = mi->settings.default_pay_delay;
   if (no_refund_delay)
     is.default_refund_delay = mi->settings.default_refund_delay;
+  if (GNUNET_TIME_relative_is_forever (is.default_pay_delay))
+  {
+    GNUNET_break_op (0);
+    GNUNET_JSON_parse_free (spec);
+    return TALER_MHD_reply_with_error (connection,
+                                       MHD_HTTP_BAD_REQUEST,
+                                       TALER_EC_GENERIC_PARAMETER_MALFORMED,
+                                       "default_pay_delay");
+  }
+  if (GNUNET_TIME_relative_is_forever (is.default_refund_delay))
+  {
+    GNUNET_break_op (0);
+    GNUNET_JSON_parse_free (spec);
+    return TALER_MHD_reply_with_error (connection,
+                                       MHD_HTTP_BAD_REQUEST,
+                                       TALER_EC_GENERIC_PARAMETER_MALFORMED,
+                                       "default_refund_delay");
+  }
+  if (GNUNET_TIME_relative_is_forever (is.default_wire_transfer_delay))
+  {
+    GNUNET_break_op (0);
+    GNUNET_JSON_parse_free (spec);
+    return TALER_MHD_reply_with_error (connection,
+                                       MHD_HTTP_BAD_REQUEST,
+                                       TALER_EC_GENERIC_PARAMETER_MALFORMED,
+                                       "default_wire_transfer_delay");
+  }
 
   if ( (NULL != is.phone) &&
        (NULL != mi->settings.phone) &&
