@@ -1,6 +1,6 @@
 /*
   This file is part of TALER
-  (C) 2020-2024 Taler Systems SA
+  (C) 2020-2025 Taler Systems SA
 
   TALER is free software; you can redistribute it and/or modify
   it under the terms of the GNU Affero General Public License as
@@ -41,6 +41,11 @@ TMH_private_post_products (const struct TMH_RequestHandler *rh,
   struct GNUNET_JSON_Specification spec[] = {
     GNUNET_JSON_spec_string ("product_id",
                              &product_id),
+    /* new in protocol v20, thus optional for backwards-compatibility */
+    GNUNET_JSON_spec_mark_optional (
+      GNUNET_JSON_spec_string ("product_name",
+                               (const char **) &pd.product_name),
+      NULL),
     GNUNET_JSON_spec_string ("description",
                              (const char **) &pd.description),
     GNUNET_JSON_spec_mark_optional (
@@ -101,6 +106,10 @@ TMH_private_post_products (const struct TMH_RequestHandler *rh,
              ? MHD_YES
              : MHD_NO;
     }
+    /* For pre-v20 clients, we use the description given as the
+       product name; remove once we make product_name mandatory. */
+    if (NULL == pd.product_name)
+      pd.product_name = pd.description;
   }
   if (total_stock < -1)
   {
