@@ -76,7 +76,7 @@ CREATE INDEX IF NOT EXISTS merchant_deposits_by_deposit_confirmation_serial
 CREATE TABLE IF NOT EXISTS merchant_token_families
   (token_family_serial BIGINT GENERATED BY DEFAULT AS IDENTITY PRIMARY KEY
   ,merchant_serial BIGINT NOT NULL REFERENCES merchant_instances (merchant_serial) ON DELETE CASCADE
-  ,slug TEXT NOT NULL UNIQUE
+  ,slug TEXT NOT NULL UNIQUE -- Constraint fixed in merchant-0013!
   ,name TEXT NOT NULL
   ,description TEXT
   ,description_i18n BYTEA NOT NULL
