@@ -25,6 +25,20 @@
 #include <taler/taler_json_lib.h>
 #include "taler_merchantdb_plugin.h"
 
+/**
+ * Delete login token from database by serial.
+ *
+ * @param cls closure
+ * @param id identifier of the instance
+ * @param serial serial of the token
+ * @return database result code
+ */
+enum GNUNET_DB_QueryStatus
+TMH_PG_delete_login_token_serial (
+  void *cls,
+  const char *id,
+  uint64_t serial);
+
 
 /**
  * Delete login token from database.
