@@ -29,14 +29,12 @@
  * Insert information about an instance's account into our database.
  *
  * @param cls closure
- * @param id identifier of the instance
  * @param account_details details about the account
  * @return database result code
  */
 enum GNUNET_DB_QueryStatus
 TMH_PG_insert_account (
   void *cls,
-  const char *id,
   const struct TALER_MERCHANTDB_AccountDetails *account_details);
 
 
