@@ -55,7 +55,7 @@ TMH_PG_insert_category (void *cls,
            ",category_name_i18n"
            ")"
            " SELECT merchant_serial,"
-           " $2, $3"
+           " $2, $3::TEXT::JSONB"
            " FROM merchant_instances"
            " WHERE merchant_id=$1"
            " RETURNING category_serial");
