@@ -36,6 +36,8 @@
  * @param amount_with_fee amount the exchange will deposit for this coin
  * @param deposit_fee fee the exchange will charge for this coin
  * @param refund_fee fee the exchange charges to refund this coin
+ * @param check_time at what time should we check the deposit status
+ *        with the exchange (for settlement)
  * @return transaction status
  */
 enum GNUNET_DB_QueryStatus
@@ -47,6 +49,7 @@ TMH_PG_insert_deposit (
   const struct TALER_CoinSpendSignatureP *coin_sig,
   const struct TALER_Amount *amount_with_fee,
   const struct TALER_Amount *deposit_fee,
-  const struct TALER_Amount *refund_fee);
+  const struct TALER_Amount *refund_fee,
+  struct GNUNET_TIME_Absolute check_time);
 
 #endif
