@@ -31,10 +31,13 @@
  *
  * @param cls plugin closure
  * @param keys data to store
+ * @param first_retry earliest we may retry fetching the keys
  * @return transaction status
  */
 enum GNUNET_DB_QueryStatus
-TMH_PG_insert_exchange_keys (void *cls,
-                             const struct TALER_EXCHANGE_Keys *keys);
+TMH_PG_insert_exchange_keys (
+  void *cls,
+  const struct TALER_EXCHANGE_Keys *keys,
+  struct GNUNET_TIME_Absolute first_retry);
 
 #endif
