@@ -1,6 +1,6 @@
 /*
    This file is part of TALER
-   Copyright (C) 2024 Taler Systems SA
+   Copyright (C) 2024, 2025 Taler Systems SA
 
    TALER is free software; you can redistribute it and/or modify it under the
    terms of the GNU General Public License as published by the Free Software
@@ -35,29 +35,44 @@ TMH_PG_insert_issued_token (void *cls,
                             blind_sig)
 {
   struct PostgresClosure *pg = cls;
-
   struct GNUNET_PQ_QueryParam params[] = {
     GNUNET_PQ_query_param_auto_from_type (h_issue_pub),
     GNUNET_PQ_query_param_auto_from_type (h_contract_terms),
     GNUNET_PQ_query_param_blinded_sig (blind_sig->signature),
     GNUNET_PQ_query_param_end
   };
+  bool no_fam;
+  bool existed;
+  struct GNUNET_PQ_ResultSpec rs[] = {
+    GNUNET_PQ_result_spec_bool ("out_no_family",
+                                &no_fam),
+    GNUNET_PQ_result_spec_bool ("out_existed",
+                                &existed),
+    GNUNET_PQ_result_spec_end
+  };
+  enum GNUNET_DB_QueryStatus qs;
 
   check_connection (pg);
   PREPARE (pg,
            "issued_token_insert",
-           "INSERT INTO merchant_issued_tokens"
-           "(token_family_key_serial"
-           ",h_contract_terms"
-           ",blind_sig)"
-           " SELECT token_family_key_serial, $2, $3"
-           " FROM merchant_token_families"
-           " JOIN merchant_token_family_keys"
-           "   USING (token_family_serial)"
-           " WHERE h_pub = $1");
-
-  /* FIXME-#9434: Increase issued counter on merchant_token_family table. */
-  return GNUNET_PQ_eval_prepared_non_select (pg->conn,
-                                             "issued_token_insert",
-                                             params);
+           "SELECT"
+           "  out_no_family"
+           " ,out_existed"
+           "  FROM merchant_do_insert_issued_token"
+           " ($1, $2, $3);");
+  qs = GNUNET_PQ_eval_prepared_singleton_select (
+    pg->conn,
+    "issued_token_insert",
+    params,
+    rs);
+  if (qs < 0)
+    return qs;
+  if (no_fam)
+  {
+    GNUNET_break (0);
+    return GNUNET_DB_STATUS_HARD_ERROR;
+  }
+  if (existed)
+    return GNUNET_DB_STATUS_SUCCESS_NO_RESULTS;
+  return qs;
 }
