@@ -1,6 +1,6 @@
 /*
    This file is part of TALER
-   Copyright (C) 2022, 2023 Taler Systems SA
+   Copyright (C) 2022, 2023, 2025 Taler Systems SA
 
    TALER is free software; you can redistribute it and/or modify it under the
    terms of the GNU General Public License as published by the Free Software
@@ -86,7 +86,7 @@ TMH_PG_insert_order (void *cls,
            ",session_id"
            ",fulfillment_url)"
            " SELECT merchant_serial,"
-           " $2, $3, $4, $5, $6, $7, $8, $9, $10, $11"
+           " $2, $3, $4, $5, $6, $7::TEXT::JSONB, $8, $9, $10, $11"
            " FROM merchant_instances"
            " WHERE merchant_id=$1");
   return GNUNET_PQ_eval_prepared_non_select (pg->conn,
