@@ -42,6 +42,6 @@ TMH_PG_insert_spent_token (
   const struct TALER_TokenIssuePublicKeyHashP *h_issue_pub,
   const struct TALER_TokenUsePublicKeyP *use_pub,
   const struct TALER_TokenUseSignatureP *use_sig,
-  const struct TALER_TokenIssueSignatureP *issue_sig);
+  const struct TALER_TokenIssueSignature *issue_sig);
 
 #endif
