@@ -28,13 +28,13 @@
 enum GNUNET_DB_QueryStatus
 TMH_PG_lookup_account (void *cls,
                        const char *instance_id,
-                       const char *payto_uri,
+                       struct TALER_FullPayto payto_uri,
                        uint64_t *account_serial)
 {
   struct PostgresClosure *pg = cls;
   struct GNUNET_PQ_QueryParam params[] = {
     GNUNET_PQ_query_param_string (instance_id),
-    GNUNET_PQ_query_param_string (payto_uri),
+    GNUNET_PQ_query_param_string (payto_uri.full_payto),
     GNUNET_PQ_query_param_end
   };
   struct GNUNET_PQ_ResultSpec rs[] = {
