@@ -59,7 +59,7 @@ TMH_PG_lookup_contract_terms (
   PREPARE (pg,
            "lookup_contract_terms",
            "SELECT"
-           " contract_terms"
+           " contract_terms::TEXT"
            ",order_serial"
            ",claim_token"
            " FROM merchant_contract_terms"
