@@ -45,16 +45,16 @@ TMH_PG_lookup_product (void *cls,
            "lookup_product",
            "SELECT"
            " mi.description"
-           ",mi.description_i18n"
+           ",mi.description_i18n::TEXT"
            ",mi.product_name"
            ",mi.unit"
            ",mi.price"
-           ",mi.taxes"
+           ",mi.taxes::TEXT"
            ",mi.total_stock"
            ",mi.total_sold"
            ",mi.total_lost"
            ",mi.image"
-           ",mi.address"
+           ",mi.address::TEXT"
            ",mi.next_restock"
            ",mi.minimum_age"
            ",t.category_array AS categories"
