@@ -61,7 +61,7 @@ TMH_PG_lookup_token_family_key (
            ",slug"
            ",name"
            ",description"
-           ",description_i18n"
+           ",description_i18n::TEXT"
            ",mtf.valid_after"
            ",mtf.valid_before"
            ",duration"
