@@ -194,7 +194,7 @@ TMH_PG_lookup_token_family_keys (
            ",slug"
            ",name"
            ",description"
-           ",description_i18n"
+           ",description_i18n::TEXT"
            ",mtf.valid_after"
            ",mtf.valid_before"
            ",duration"
