@@ -76,9 +76,8 @@ lookup_transfers_cb (void *cls,
     struct TALER_FullPayto payto_uri;
     char *exchange_url;
     uint64_t transfer_serial_id;
-    struct GNUNET_TIME_Timestamp execution_time = GNUNET_TIME_UNIT_FOREVER_TS;
-    bool verified;
-    bool confirmed;
+    struct GNUNET_TIME_Absolute execution_time;
+    bool expected;
     struct GNUNET_PQ_ResultSpec rs[] = {
       TALER_PQ_result_spec_amount_with_currency ("credit_amount",
                                                  &credit_amount),
@@ -90,14 +89,10 @@ lookup_transfers_cb (void *cls,
                                     &exchange_url),
       GNUNET_PQ_result_spec_uint64 ("credit_serial",
                                     &transfer_serial_id),
-      GNUNET_PQ_result_spec_allow_null (
-        GNUNET_PQ_result_spec_timestamp ("execution_time",
-                                         &execution_time),
-        NULL),
-      GNUNET_PQ_result_spec_bool ("verified",
-                                  &verified),
-      GNUNET_PQ_result_spec_bool ("confirmed",
-                                  &confirmed),
+      GNUNET_PQ_result_spec_absolute_time ("execution_time",
+                                           &execution_time),
+      GNUNET_PQ_result_spec_bool ("expected",
+                                  &expected),
       GNUNET_PQ_result_spec_end
     };
 
@@ -117,8 +112,7 @@ lookup_transfers_cb (void *cls,
              exchange_url,
              transfer_serial_id,
              execution_time,
-             verified,
-             confirmed);
+             expected);
     GNUNET_PQ_cleanup_result (rs);
   }
   ltc->qs = num_results;
@@ -133,7 +127,7 @@ TMH_PG_lookup_transfers (void *cls,
                          struct GNUNET_TIME_Timestamp after,
                          int64_t limit,
                          uint64_t offset,
-                         enum TALER_EXCHANGE_YesNoAll verified,
+                         enum TALER_EXCHANGE_YesNoAll expected,
                          TALER_MERCHANTDB_TransferCallback cb,
                          void *cb_cls)
 {
@@ -156,8 +150,9 @@ TMH_PG_lookup_transfers (void *cls,
     ? GNUNET_PQ_query_param_null () /* NULL: do not filter by payto URI */
     : GNUNET_PQ_query_param_string (payto_uri.full_payto),
     GNUNET_PQ_query_param_bool (! by_time),     /* $7: filter by time? */
-    GNUNET_PQ_query_param_bool (TALER_EXCHANGE_YNA_ALL == verified), /* filter by verified? */
-    GNUNET_PQ_query_param_bool (TALER_EXCHANGE_YNA_YES == verified),
+    GNUNET_PQ_query_param_bool (TALER_EXCHANGE_YNA_ALL == expected), /* filter by expected? */
+    GNUNET_PQ_query_param_bool (TALER_EXCHANGE_YNA_YES == expected),
+
     GNUNET_PQ_query_param_end
   };
   enum GNUNET_DB_QueryStatus qs;
@@ -167,65 +162,57 @@ TMH_PG_lookup_transfers (void *cls,
            "lookup_transfers_asc",
            "SELECT"
            " mt.credit_amount"
-           ",wtid"
+           ",mt.wtid"
            ",mac.payto_uri"
-           ",exchange_url"
-           ",credit_serial"
-           ",mts.execution_time"
-           ",verified"
-           ",confirmed"
+           ",mt.exchange_url"
+           ",mt.credit_serial"
+           ",mt.execution_time"
+           ",mt.expected"
            " FROM merchant_transfers mt"
            "  JOIN merchant_accounts mac"
            "    USING (account_serial)"
-           "  LEFT JOIN merchant_transfer_signatures mts"
-           "    USING (credit_serial)"
            " WHERE ( $7 OR "
-           "         (mts.execution_time IS NOT NULL AND"
-           "          mts.execution_time < $2 AND"
-           "          mts.execution_time >= $3) )"
-           "   AND ( $8 OR "
-           "         (verified = $9) )"
+           "         (mt.execution_time < $2 AND"
+           "          mt.execution_time >= $3) )"
            "   AND ( (CAST($6 AS TEXT) IS NULL) OR "
            "         (REGEXP_REPLACE(mac.payto_uri,'\\?.*','')"
            "         =REGEXP_REPLACE($6,'\\?.*','')) )"
+           "   AND ( $8 OR "
+           "         (mt.expected = $9) )"
            "   AND merchant_serial ="
            "     (SELECT merchant_serial"
            "        FROM merchant_instances"
            "       WHERE merchant_id=$1)"
-           "   AND (credit_serial > $4)"
-           " ORDER BY credit_serial ASC"
+           "   AND (mt.credit_serial > $4)"
+           " ORDER BY mt.credit_serial ASC"
            " LIMIT $5");
   PREPARE (pg,
            "lookup_transfers_desc",
            "SELECT"
            " mt.credit_amount"
-           ",wtid"
+           ",mt.wtid"
            ",mac.payto_uri"
-           ",exchange_url"
-           ",credit_serial"
-           ",mts.execution_time"
-           ",verified"
-           ",confirmed"
+           ",mt.exchange_url"
+           ",mt.credit_serial"
+           ",mt.execution_time"
+           ",mt.expected"
            " FROM merchant_transfers mt"
            "  JOIN merchant_accounts mac"
            "    USING (account_serial)"
-           "  LEFT JOIN merchant_transfer_signatures mts"
-           "    USING (credit_serial)"
            " WHERE ( $7 OR "
-           "         (mts.execution_time IS NOT NULL AND"
-           "          mts.execution_time < $2 AND"
-           "          mts.execution_time >= $3) )"
-           "   AND ( $8 OR "
-           "         (verified = $9) )"
+           "         (mt.execution_time < $2 AND"
+           "          mt.execution_time >= $3) )"
            "   AND ( (CAST($6 AS TEXT) IS NULL) OR "
            "         (REGEXP_REPLACE(mac.payto_uri,'\\?.*','')"
            "         =REGEXP_REPLACE($6,'\\?.*','')) )"
+           "   AND ( $8 OR "
+           "         (mt.expected = $9) )"
            "   AND merchant_serial ="
            "     (SELECT merchant_serial"
            "        FROM merchant_instances"
            "       WHERE merchant_id=$1)"
-           "   AND (credit_serial < $4)"
-           " ORDER BY credit_serial DESC"
+           "   AND (mt.credit_serial < $4)"
+           " ORDER BY mt.credit_serial DESC"
            " LIMIT $5");
   qs = GNUNET_PQ_eval_prepared_multi_select (
     pg->conn,
