@@ -129,8 +129,8 @@ TMH_PG_select_accounts_by_exchange (
            "SELECT"
            " payto_uri"
            ",conversion_url"
-           ",debit_restrictions"
-           ",credit_restrictions"
+           ",debit_restrictions::TEXT"
+           ",credit_restrictions::TEXT"
            ",master_sig"
            " FROM merchant_exchange_accounts"
            " WHERE master_pub=$1;");
