@@ -73,7 +73,7 @@ TMH_PG_select_category (
              "select_category",
              "SELECT"
              " category_name"
-             ",category_name_i18n"
+             ",category_name_i18n::TEXT"
              ",t.product_array AS products"
              " FROM merchant_categories mc"
              " JOIN merchant_instances inst"
