@@ -1,6 +1,6 @@
 /*
    This file is part of TALER
-   Copyright (C) 2022 Taler Systems SA
+   Copyright (C) 2022, 2025 Taler Systems SA
 
    TALER is free software; you can redistribute it and/or modify it under the
    terms of the GNU General Public License as published by the Free Software
@@ -75,10 +75,9 @@ open_transfers_cb (void *cls,
     char *exchange_url;
     struct TALER_FullPayto payto_uri;
     struct TALER_WireTransferIdentifierRawP wtid;
-    struct TALER_Amount total;
-    struct GNUNET_TIME_Absolute next_attempt;
+    struct GNUNET_TIME_Absolute retry_time;
     struct GNUNET_PQ_ResultSpec rs[] = {
-      GNUNET_PQ_result_spec_uint64 ("credit_serial",
+      GNUNET_PQ_result_spec_uint64 ("expected_credit_serial",
                                     &rowid),
       GNUNET_PQ_result_spec_string ("instance_id",
                                     &instance_id),
@@ -88,10 +87,8 @@ open_transfers_cb (void *cls,
                                     &payto_uri.full_payto),
       GNUNET_PQ_result_spec_auto_from_type ("wtid",
                                             &wtid),
-      TALER_PQ_result_spec_amount_with_currency ("credit_amount",
-                                                 &total),
-      GNUNET_PQ_result_spec_absolute_time ("next_attempt",
-                                           &next_attempt),
+      GNUNET_PQ_result_spec_absolute_time ("retry_time",
+                                           &retry_time),
       GNUNET_PQ_result_spec_end
     };
 
@@ -110,8 +107,7 @@ open_transfers_cb (void *cls,
              exchange_url,
              payto_uri,
              &wtid,
-             &total,
-             next_attempt);
+             retry_time);
     GNUNET_PQ_cleanup_result (rs);
   }
 }
@@ -138,23 +134,20 @@ TMH_PG_select_open_transfers (void *cls,
   PREPARE (pg,
            "select_open_transfers",
            "SELECT"
-           " credit_serial"
-           ",merchant_id AS instance_id"
-           ",exchange_url"
-           ",payto_uri"
-           ",wtid"
-           ",credit_amount"
-           ",ready_time AS next_attempt"
-           " FROM merchant_transfers"
-           " JOIN merchant_accounts"
+           " met.expected_credit_serial"
+           ",mi.merchant_id AS instance_id"
+           ",met.exchange_url"
+           ",ma.payto_uri"
+           ",met.wtid"
+           ",met.retry_time"
+           " FROM merchant_expected_transfers met"
+           " JOIN merchant_accounts ma"
            "   USING (account_serial)"
-           " JOIN merchant_instances"
-           "   USING (merchant_serial)"
-           " WHERE confirmed AND"
-           "       NOT (failed OR verified)"
-           " ORDER BY ready_time ASC"
+           " JOIN merchant_instances mi"
+           "   ON (ma.merchant_serial=mi.merchant_serial)"
+           " WHERE retry_needed"
+           " ORDER BY retry_time ASC"
            " LIMIT $1;");
-
   qs = GNUNET_PQ_eval_prepared_multi_select (
     pg->conn,
     "select_open_transfers",
