@@ -129,7 +129,7 @@ TMH_PG_select_wirewatch_accounts (
            ",merchant_id"
            ",payto_uri"
            ",credit_facade_url"
-           ",credit_facade_credentials"
+           ",credit_facade_credentials::TEXT"
            " FROM merchant_accounts"
            " JOIN merchant_instances"
            "   USING (merchant_serial)"
