@@ -30,35 +30,36 @@ enum GNUNET_DB_QueryStatus
 TMH_PG_update_deposit_confirmation_status (
   void *cls,
   uint64_t deposit_serial,
-  bool wire_pending,
-  struct GNUNET_TIME_Timestamp future_retry,
-  struct GNUNET_TIME_Relative retry_backoff,
-  const char *emsg)
+  bool retry_needed,
+  struct GNUNET_TIME_Timestamp retry_time,
+  uint32_t last_http_status,
+  enum TALER_ErrorCode last_ec,
+  const char *last_detail)
 {
   struct PostgresClosure *pg = cls;
+  uint32_t ec32 = (uint32_t) last_ec;
   struct GNUNET_PQ_QueryParam params[] = {
     GNUNET_PQ_query_param_uint64 (&deposit_serial),
-    GNUNET_PQ_query_param_timestamp (&future_retry),
-    NULL == emsg
+    GNUNET_PQ_query_param_bool (retry_needed),
+    GNUNET_PQ_query_param_timestamp (&retry_time),
+    GNUNET_PQ_query_param_uint32 (&last_http_status),
+    GNUNET_PQ_query_param_uint32 (&ec32),
+    NULL == last_detail
     ? GNUNET_PQ_query_param_null ()
-    : GNUNET_PQ_query_param_string (emsg),
-    GNUNET_PQ_query_param_relative_time (&retry_backoff),
-    GNUNET_PQ_query_param_bool (wire_pending),
+    : GNUNET_PQ_query_param_string (last_detail),
     GNUNET_PQ_query_param_end
   };
 
   check_connection (pg);
   PREPARE (pg,
            "update_deposit_confirmation_status",
-           "UPDATE merchant_deposit_confirmations SET"
-           " wire_transfer_deadline=$2"
-           ",exchange_failure=$3"
-           ",retry_backoff=$4"
-           ",wire_pending=$5 AND wire_pending"
-           " WHERE deposit_confirmation_serial="
-           "   (SELECT deposit_confirmation_serial"
-           "      FROM merchant_deposits"
-           "      WHERE deposit_serial=$1);");
+           "UPDATE merchant_deposits SET"
+           " settlement_retry_needed=$2"
+           ",settlement_retry_time=$3"
+           ",settlement_last_http_status=$4"
+           ",settlement_last_ec=$5"
+           ",settlement_last_detail=$6"
+           " WHERE deposit_serial=$1;");
   return GNUNET_PQ_eval_prepared_non_select (
     pg->conn,
     "update_deposit_confirmation_status",
