@@ -20,14 +20,14 @@ CREATE FUNCTION merchant_do_update_product (
   IN in_instance_id TEXT,
   IN in_product_id TEXT,
   IN in_description TEXT,
-  IN in_description_i18n BYTEA,
+  IN in_description_i18n JSONB,
   IN in_unit TEXT,
   IN in_image TEXT,
-  IN in_taxes BYTEA,
+  IN in_taxes JSONB,
   IN in_price taler_amount_currency,
   IN in_total_stock INT8,
   IN in_total_lost INT8,
-  IN in_address BYTEA,
+  IN in_address JSONB,
   IN in_next_restock INT8,
   IN in_minimum_age INT4,
   IN ina_categories INT8[],
@@ -126,6 +126,13 @@ UPDATE merchant_inventory SET
   ,product_name=in_product_name
   ,unit=in_unit
   ,image=in_image
+  ,image_hash=CASE
+               WHEN (in_image IS NULL) OR (in_image = '')
+               THEN NULL
+               ELSE encode(public.digest(convert_to(in_image, 'UTF8'),
+                                  'sha256'),
+                           'hex')
+             END
   ,taxes=in_taxes
   ,price=in_price
   ,total_stock=in_total_stock
