@@ -44,9 +44,6 @@ TMH_PG_update_template (void *cls,
     (NULL == td->editable_defaults)
     ? GNUNET_PQ_query_param_null ()
     : TALER_PQ_query_param_json (td->editable_defaults),
-    (NULL == td->required_currency)
-    ? GNUNET_PQ_query_param_null ()
-    : GNUNET_PQ_query_param_string (td->required_currency),
     GNUNET_PQ_query_param_end
   };
 
@@ -67,9 +64,8 @@ TMH_PG_update_template (void *cls,
            ",otp_device_id="
            "  COALESCE((SELECT otp_serial"
            "            FROM otp), NULL)"
-           ",template_contract=$5"
-           ",editable_defaults=$6"
-           ",required_currency=$7"
+           ",template_contract=$5::TEXT::JSONB"
+           ",editable_defaults=$6::TEXT::JSONB"
            " WHERE merchant_serial="
            "   (SELECT merchant_serial"
            "      FROM mid)"
