@@ -81,6 +81,7 @@
 #include "pg_lookup_products.h"
 #include "pg_lookup_all_products.h"
 #include "pg_lookup_product.h"
+#include "pg_lookup_product_image.h"
 #include "pg_delete_product.h"
 #include "pg_insert_product.h"
 #include "pg_update_product.h"
@@ -463,6 +464,8 @@ libtaler_plugin_merchantdb_postgres_init (void *cls)
     = &TMH_PG_lookup_all_products;
   plugin->lookup_product
     = &TMH_PG_lookup_product;
+  plugin->lookup_product_image_by_hash
+    = &TMH_PG_lookup_product_image_by_hash;
   plugin->delete_product
     = &TMH_PG_delete_product;
   plugin->insert_product
