@@ -105,13 +105,13 @@ CREATE FUNCTION merchant_do_insert_product (
   IN in_instance_id TEXT,
   IN in_product_id TEXT,
   IN in_description TEXT,
-  IN in_description_i18n BYTEA,
+  IN in_description_i18n JSONB,
   IN in_unit TEXT,
   IN in_image TEXT,
-  IN in_taxes BYTEA,
+  IN in_taxes JSONB,
   IN in_price taler_amount_currency,
   IN in_total_stock INT8,
-  IN in_address BYTEA,
+  IN in_address JSONB,
   IN in_next_restock INT8,
   IN in_minimum_age INT4,
   IN ina_categories INT8[],
@@ -147,12 +147,13 @@ INSERT INTO merchant_inventory
  ,description_i18n
  ,unit
  ,image
+ ,image_hash
  ,taxes
  ,price
  ,total_stock
  ,address
  ,next_restock
- ,minimum_age
+  ,minimum_age
 ) VALUES (
   my_merchant_id
  ,in_product_id
@@ -161,6 +162,13 @@ INSERT INTO merchant_inventory
  ,in_description_i18n
  ,in_unit
  ,in_image
+ ,CASE
+    WHEN (in_image IS NULL) OR (in_image = '')
+    THEN NULL
+    ELSE encode(public.digest(convert_to(in_image, 'UTF8'),
+                       'sha256'),
+                'hex')
+  END
  ,in_taxes
  ,in_price
  ,in_total_stock
@@ -561,14 +569,14 @@ CREATE FUNCTION merchant_do_update_product (
   IN in_instance_id TEXT,
   IN in_product_id TEXT,
   IN in_description TEXT,
-  IN in_description_i18n BYTEA,
+  IN in_description_i18n JSONB,
   IN in_unit TEXT,
   IN in_image TEXT,
-  IN in_taxes BYTEA,
+  IN in_taxes JSONB,
   IN in_price taler_amount_currency,
   IN in_total_stock INT8,
   IN in_total_lost INT8,
-  IN in_address BYTEA,
+  IN in_address JSONB,
   IN in_next_restock INT8,
   IN in_minimum_age INT4,
   IN ina_categories INT8[],
@@ -650,6 +658,13 @@ UPDATE merchant_inventory SET
   ,product_name=in_product_name
   ,unit=in_unit
   ,image=in_image
+  ,image_hash=CASE
+               WHEN (in_image IS NULL) OR (in_image = '')
+               THEN NULL
+               ELSE encode(public.digest(convert_to(in_image, 'UTF8'),
+                                  'sha256'),
+                           'hex')
+             END
   ,taxes=in_taxes
   ,price=in_price
   ,total_stock=in_total_stock
@@ -728,7 +743,7 @@ CREATE FUNCTION merchant_do_account_kyc_set_status (
   IN in_exchange_http_status INT4,
   IN in_exchange_ec_code INT4,
   IN in_access_token BYTEA, 
-  IN in_jlimits TEXT,
+  IN in_jlimits JSONB,
   IN in_aml_active BOOL,
   IN in_kyc_ok BOOL,
   IN in_notify_str TEXT,
@@ -1841,6 +1856,380 @@ BEGIN
 END $$;
 COMMENT ON FUNCTION merchant_statistics_bucket_end
 IS 'computes the end time of the bucket for an event at the current time given the desired bucket range';
+CREATE OR REPLACE FUNCTION handle_inventory_changes()
+  RETURNS TRIGGER AS $$
+DECLARE
+  my_merchant_serial BIGINT;
+  resolved_body TEXT;
+  webhook RECORD; 
+BEGIN
+  my_merchant_serial := COALESCE(OLD.merchant_serial, NEW.merchant_serial);
+  IF TG_OP = 'INSERT' THEN
+    FOR webhook IN
+      SELECT webhook_serial,
+             merchant_serial,
+      url,
+      http_method,
+      body_template
+      FROM merchant.merchant_webhook
+      WHERE event_type = 'inventory_added'
+        AND merchant_serial = my_merchant_serial
+      LOOP
+        resolved_body := webhook.body_template;
+        resolved_body := replace_placeholder(resolved_body,
+                                             'webhook_type',
+                                             'inventory_added');
+        resolved_body := replace_placeholder(resolved_body,
+                                             'product_serial',
+                                             NEW.product_serial::TEXT);
+        resolved_body := replace_placeholder(resolved_body,
+                                             'product_id',
+                                             NEW.product_id);
+        resolved_body := replace_placeholder(resolved_body,
+                                             'description',
+                                             NEW.description);
+        resolved_body := replace_placeholder(resolved_body,
+                                             'description_i18n',
+                                             NEW.description_i18n::TEXT);
+        resolved_body := replace_placeholder(resolved_body,
+                                             'unit',
+                                             NEW.unit);
+        resolved_body := replace_placeholder(resolved_body,
+                                             'image',
+                                             NEW.image);
+        resolved_body := replace_placeholder(resolved_body,
+                                             'taxes',
+                                             NEW.taxes::TEXT);
+        resolved_body := replace_placeholder(resolved_body,
+                                             'price',
+                                             NEW.price::TEXT);
+        resolved_body := replace_placeholder(resolved_body,
+                                             'total_stock',
+                                             NEW.total_stock::TEXT);
+        resolved_body := replace_placeholder(resolved_body,
+                                             'total_sold',
+                                             NEW.total_sold::TEXT);
+        resolved_body := replace_placeholder(resolved_body,
+                                             'total_lost',
+                                             NEW.total_lost::TEXT);
+        resolved_body := replace_placeholder(resolved_body,
+                                             'address',
+                                             NEW.address::TEXT);
+        resolved_body := replace_placeholder(resolved_body,
+                                             'next_restock',
+                                             NEW.next_restock::TEXT);
+        resolved_body := replace_placeholder(resolved_body,
+                                             'minimum_age',
+                                             NEW.minimum_age::TEXT);
+        INSERT INTO merchant.merchant_pending_webhooks
+        (merchant_serial, webhook_serial, url, http_method, body)
+        VALUES
+          (webhook.merchant_serial,
+           webhook.webhook_serial,
+           webhook.url,
+           webhook.http_method,
+           resolved_body);
+      END LOOP;
+    NOTIFY XXJWF6C1DCS1255RJH7GQ1EK16J8DMRSQ6K9EDKNKCP7HRVWAJPKG;
+  END IF;
+  IF TG_OP = 'UPDATE' THEN
+    FOR webhook IN
+      SELECT webhook_serial,
+             merchant_serial,
+      url,
+      http_method,
+      body_template
+      FROM merchant.merchant_webhook
+      WHERE event_type = 'inventory_updated'
+        AND merchant_serial = my_merchant_serial
+      LOOP
+        resolved_body := webhook.body_template;
+        resolved_body := replace_placeholder(resolved_body,
+                                             'webhook_type',
+                                             'inventory_updated');
+        resolved_body := replace_placeholder(resolved_body,
+                                             'product_serial',
+                                             NEW.product_serial::TEXT);
+        resolved_body := replace_placeholder(resolved_body,
+                                             'product_id',
+                                             NEW.product_id);
+        resolved_body := replace_placeholder(resolved_body,
+                                             'old_description',
+                                             OLD.description);
+        resolved_body := replace_placeholder(resolved_body,
+                                             'description',
+                                             NEW.description);
+        resolved_body := replace_placeholder(resolved_body,
+                                             'old_description_i18n',
+                                             OLD.description_i18n::TEXT);
+        resolved_body := replace_placeholder(resolved_body,
+                                             'description_i18n',
+                                             NEW.description_i18n::TEXT);
+        resolved_body := replace_placeholder(resolved_body,
+                                             'old_unit',
+                                             OLD.unit);
+        resolved_body := replace_placeholder(resolved_body,
+                                             'unit',
+                                             NEW.unit);
+        resolved_body := replace_placeholder(resolved_body,
+                                             'old_image',
+                                             OLD.image);
+        resolved_body := replace_placeholder(resolved_body,
+                                             'image',
+                                             NEW.image);
+        resolved_body := replace_placeholder(resolved_body,
+                                             'old_taxes',
+                                             OLD.taxes::TEXT);
+        resolved_body := replace_placeholder(resolved_body,
+                                             'taxes',
+                                             NEW.taxes::TEXT);
+        resolved_body := replace_placeholder(resolved_body,
+                                             'old_price',
+                                             OLD.price::TEXT);
+        resolved_body := replace_placeholder(resolved_body,
+                                             'price',
+                                             NEW.price::TEXT);
+        resolved_body := replace_placeholder(resolved_body,
+                                             'old_total_stock',
+                                             OLD.total_stock::TEXT);
+        resolved_body := replace_placeholder(resolved_body,
+                                             'total_stock',
+                                             NEW.total_stock::TEXT);
+        resolved_body := replace_placeholder(resolved_body,
+                                             'old_total_sold',
+                                             OLD.total_sold::TEXT);
+        resolved_body := replace_placeholder(resolved_body,
+                                             'total_sold',
+                                             NEW.total_sold::TEXT);
+        resolved_body := replace_placeholder(resolved_body,
+                                             'old_total_lost',
+                                             OLD.total_lost::TEXT);
+        resolved_body := replace_placeholder(resolved_body,
+                                             'total_lost',
+                                             NEW.total_lost::TEXT);
+        resolved_body := replace_placeholder(resolved_body,
+                                             'old_address',
+                                             OLD.address::TEXT);
+        resolved_body := replace_placeholder(resolved_body,
+                                             'address',
+                                             NEW.address::TEXT);
+        resolved_body := replace_placeholder(resolved_body,
+                                             'old_next_restock',
+                                             OLD.next_restock::TEXT);
+        resolved_body := replace_placeholder(resolved_body,
+                                             'next_restock',
+                                             NEW.next_restock::TEXT);
+        resolved_body := replace_placeholder(resolved_body,
+                                             'old_minimum_age',
+                                             OLD.minimum_age::TEXT);
+        resolved_body := replace_placeholder(resolved_body,
+                                             'minimum_age',
+                                             NEW.minimum_age::TEXT);
+        INSERT INTO merchant.merchant_pending_webhooks
+        (merchant_serial, webhook_serial, url, http_method, body)
+        VALUES
+          (webhook.merchant_serial,
+           webhook.webhook_serial,
+           webhook.url,
+           webhook.http_method,
+           resolved_body);
+      END LOOP;
+    NOTIFY XXJWF6C1DCS1255RJH7GQ1EK16J8DMRSQ6K9EDKNKCP7HRVWAJPKG;
+  END IF;
+  IF TG_OP = 'DELETE' THEN
+    FOR webhook IN
+      SELECT webhook_serial,
+             merchant_serial,
+      url,
+      http_method,
+      body_template
+      FROM merchant.merchant_webhook
+      WHERE event_type = 'inventory_deleted'
+        AND merchant_serial = my_merchant_serial
+      LOOP
+        resolved_body := webhook.body_template;
+        resolved_body := replace_placeholder(resolved_body,
+                                             'webhook_type',
+                                             'inventory_deleted');
+        resolved_body := replace_placeholder(resolved_body,
+                                             'product_serial',
+                                             OLD.product_serial::TEXT);
+        resolved_body := replace_placeholder(resolved_body,
+                                             'product_id',
+                                             OLD.product_id);
+        resolved_body := replace_placeholder(resolved_body,
+                                             'description',
+                                             OLD.description);
+        resolved_body := replace_placeholder(resolved_body,
+                                             'description_i18n',
+                                             OLD.description_i18n::TEXT);
+        resolved_body := replace_placeholder(resolved_body,
+                                             'unit',
+                                             OLD.unit);
+        resolved_body := replace_placeholder(resolved_body,
+                                             'image',
+                                             OLD.image);
+        resolved_body := replace_placeholder(resolved_body,
+                                             'taxes',
+                                             OLD.taxes::TEXT);
+        resolved_body := replace_placeholder(resolved_body,
+                                             'price',
+                                             OLD.price::TEXT);
+        resolved_body := replace_placeholder(resolved_body,
+                                             'total_stock',
+                                             OLD.total_stock::TEXT);
+        resolved_body := replace_placeholder(resolved_body,
+                                             'total_sold',
+                                             OLD.total_sold::TEXT);
+        resolved_body := replace_placeholder(resolved_body,
+                                             'total_lost',
+                                             OLD.total_lost::TEXT);
+        resolved_body := replace_placeholder(resolved_body,
+                                             'address',
+                                             OLD.address::TEXT);
+        resolved_body := replace_placeholder(resolved_body,
+                                             'next_restock',
+                                             OLD.next_restock::TEXT);
+        resolved_body := replace_placeholder(resolved_body,
+                                             'minimum_age',
+                                             OLD.minimum_age::TEXT);
+        INSERT INTO merchant.merchant_pending_webhooks
+        (merchant_serial, webhook_serial, url, http_method, body)
+        VALUES
+          (webhook.merchant_serial,
+           webhook.webhook_serial,
+           webhook.url,
+           webhook.http_method,
+           resolved_body);
+      END LOOP;
+    NOTIFY XXJWF6C1DCS1255RJH7GQ1EK16J8DMRSQ6K9EDKNKCP7HRVWAJPKG;
+  END IF;
+  RETURN NULL;
+END;
+$$ LANGUAGE plpgsql;
+COMMENT ON FUNCTION handle_inventory_changes
+  IS 'Function to handle inventory changes and notify webhooks';
+CREATE OR REPLACE FUNCTION handle_category_changes()
+RETURNS TRIGGER AS $$
+DECLARE
+  my_merchant_serial BIGINT;
+  resolved_body TEXT;
+  webhook RECORD; 
+BEGIN
+  my_merchant_serial := COALESCE(OLD.merchant_serial, NEW.merchant_serial);
+  IF TG_OP = 'INSERT' THEN
+    FOR webhook IN
+      SELECT webhook_serial,
+             merchant_serial,
+      url,
+      http_method,
+      body_template
+      FROM merchant.merchant_webhook
+      WHERE event_type = 'category_added'
+        AND merchant_serial = my_merchant_serial
+    LOOP
+      resolved_body := webhook.body_template;
+      resolved_body := replace_placeholder(resolved_body,
+                                           'webhook_type',
+                                           'category_added');
+      resolved_body := replace_placeholder(resolved_body,
+                                           'category_serial',
+                                           NEW.category_serial::TEXT);
+      resolved_body := replace_placeholder(resolved_body,
+                                           'category_name',
+                                           NEW.category_name);
+      resolved_body := replace_placeholder(resolved_body,
+                                           'merchant_serial',
+                                           my_merchant_serial::TEXT);
+      INSERT INTO merchant.merchant_pending_webhooks
+      (merchant_serial, webhook_serial, url, http_method, body)
+      VALUES
+      (webhook.merchant_serial,
+       webhook.webhook_serial,
+       webhook.url,
+       webhook.http_method,
+       resolved_body);
+    END LOOP;
+    NOTIFY XXJWF6C1DCS1255RJH7GQ1EK16J8DMRSQ6K9EDKNKCP7HRVWAJPKG;
+  END IF;
+  IF TG_OP = 'UPDATE' THEN
+    FOR webhook IN
+      SELECT webhook_serial,
+             merchant_serial,
+      url,
+      http_method,
+      body_template
+      FROM merchant.merchant_webhook
+      WHERE event_type = 'category_updated'
+        AND merchant_serial = my_merchant_serial
+    LOOP
+      resolved_body := webhook.body_template;
+      resolved_body := replace_placeholder(resolved_body,
+                                           'webhook_type',
+                                           'category_updated');
+      resolved_body := replace_placeholder(resolved_body,
+                                           'category_serial',
+                                           NEW.category_serial::TEXT);
+      resolved_body := replace_placeholder(resolved_body,
+                                           'old_category_name',
+                                           OLD.category_name);
+      resolved_body := replace_placeholder(resolved_body,
+                                           'category_name',
+                                           NEW.category_name);
+      resolved_body := replace_placeholder(resolved_body,
+                                           'category_name_i18n',
+                                           NEW.category_name_i18n::TEXT);
+      resolved_body := replace_placeholder(resolved_body,
+                                           'old_category_name_i18n',
+                                           OLD.category_name_i18n::TEXT);
+      INSERT INTO merchant.merchant_pending_webhooks
+        (merchant_serial, webhook_serial, url, http_method, body)
+      VALUES
+        (webhook.merchant_serial,
+         webhook.webhook_serial,
+         webhook.url,
+         webhook.http_method,
+         resolved_body);
+    END LOOP;
+    NOTIFY XXJWF6C1DCS1255RJH7GQ1EK16J8DMRSQ6K9EDKNKCP7HRVWAJPKG;
+  END IF;
+  IF TG_OP = 'DELETE' THEN
+    FOR webhook IN
+      SELECT webhook_serial,
+             merchant_serial,
+      url,
+      http_method,
+      body_template
+      FROM merchant.merchant_webhook
+      WHERE event_type = 'category_deleted'
+        AND merchant_serial = my_merchant_serial
+    LOOP
+      resolved_body := webhook.body_template;
+      resolved_body := replace_placeholder(resolved_body,
+                                           'webhook_type',
+                                           'category_deleted');
+      resolved_body := replace_placeholder(resolved_body,
+                                           'category_serial',
+                                           OLD.category_serial::TEXT);
+      resolved_body := replace_placeholder(resolved_body,
+                                           'category_name',
+                                           OLD.category_name);
+      INSERT INTO merchant.merchant_pending_webhooks
+      (merchant_serial, webhook_serial, url, http_method, body)
+      VALUES
+      (webhook.merchant_serial,
+       webhook.webhook_serial,
+       webhook.url,
+       webhook.http_method,
+       resolved_body);
+    END LOOP;
+    NOTIFY XXJWF6C1DCS1255RJH7GQ1EK16J8DMRSQ6K9EDKNKCP7HRVWAJPKG;
+  END IF;
+  RETURN NULL;
+END;
+$$ LANGUAGE plpgsql;
+COMMENT ON FUNCTION handle_category_changes
+  IS 'Trigger function to handle pending webhooks for category changes';
 DROP PROCEDURE IF EXISTS merchant_do_gc;
 CREATE PROCEDURE merchant_do_gc(in_now INT8)
 LANGUAGE plpgsql
