@@ -38,7 +38,7 @@
 
 
 #define MERCHANT_FAIL() \
-        do {GNUNET_break (0); return NULL; } while (0)
+  do {GNUNET_break (0); return NULL; } while (0)
 
 
 /**
@@ -497,6 +497,13 @@ TALER_TESTING_cmd_merchant_get_product (const char *label,
                                         unsigned int http_status,
                                         const char *product_reference);
 
+struct TALER_TESTING_Command
+TALER_TESTING_cmd_get_product_image (const char *label,
+                                     const char *merchant_url,
+                                     const char *product_reference,
+                                     const char *image_hash,
+                                     unsigned int http_status);
+
 
 /**
  * Define a "LOCK /products/$ID" CMD.
@@ -2047,53 +2054,53 @@ TALER_TESTING_cmd_merchant_get_statisticsamount (const char *label,
  */
 // FIXME: rename: refund_entry->refund_detail
 #define TALER_MERCHANT_TESTING_SIMPLE_TRAITS(op) \
-        op (claim_nonce, const struct GNUNET_CRYPTO_EddsaPublicKey) \
-        op (pickup_id, const struct TALER_PickupIdentifierP) \
-        op (instance_name, const char) \
-        op (instance_id, const char) \
-        op (address, const json_t) \
-        op (product_description, const char) \
-        op (product_image, const char) \
-        op (product_stock, const int64_t) \
-        op (product_unit, const char) \
-        op (product_id, const char) \
-        op (reason, const char) \
-        op (lock_uuid, const char) \
-        op (auth_token, const char) \
-        op (bearer_token, const char) \
-        op (paths_length, const uint32_t) \
-        op (payto_length, const uint32_t) \
-        op (num_planchets, const uint32_t) \
-        op (i18n_description, const json_t) \
-        op (taxes, const json_t)      \
-        op (fee, const struct TALER_Amount) \
-        op (use_stefan, const bool) \
-        op (jurisdiction, const json_t) \
-        op (wire_delay, const struct GNUNET_TIME_Relative) \
-        op (pay_delay, const struct GNUNET_TIME_Relative) \
-        op (refund_entry, const struct TALER_MERCHANT_RefundDetail) \
-        op (order_terms, const json_t) \
-        op (h_contract_terms, const struct TALER_PrivateContractHashP) \
-        op (h_wire, const struct TALER_MerchantWireHashP) \
-        op (proposal_reference, const char) \
-        op (template_description, const char) \
-        op (otp_device_description, const char) \
-        op (otp_id, const char) \
-        op (otp_key, const char) \
-        op (otp_alg, const enum TALER_MerchantConfirmationAlgorithm) \
-        op (template_id, const char) \
-        op (template_contract, const json_t) \
-        op (event_type, const char)   \
-        op (webhook_id, const char) \
-        op (merchant_base_url, const char) \
-        op (url, const char) \
-        op (http_method, const char)   \
-        op (header_template, const char)   \
-        op (body_template, const char)   \
-        op (summary, const char)   \
-        op (token_family_slug, const char)   \
-        op (token_family_duration, const struct GNUNET_TIME_Relative)   \
-        op (token_family_kind, const char)
+  op (claim_nonce, const struct GNUNET_CRYPTO_EddsaPublicKey) \
+  op (pickup_id, const struct TALER_PickupIdentifierP) \
+  op (instance_name, const char) \
+  op (instance_id, const char) \
+  op (address, const json_t) \
+  op (product_description, const char) \
+  op (product_image, const char) \
+  op (product_stock, const int64_t) \
+  op (product_unit, const char) \
+  op (product_id, const char) \
+  op (reason, const char) \
+  op (lock_uuid, const char) \
+  op (auth_token, const char) \
+  op (bearer_token, const char) \
+  op (paths_length, const uint32_t) \
+  op (payto_length, const uint32_t) \
+  op (num_planchets, const uint32_t) \
+  op (i18n_description, const json_t) \
+  op (taxes, const json_t)      \
+  op (fee, const struct TALER_Amount) \
+  op (use_stefan, const bool) \
+  op (jurisdiction, const json_t) \
+  op (wire_delay, const struct GNUNET_TIME_Relative) \
+  op (pay_delay, const struct GNUNET_TIME_Relative) \
+  op (refund_entry, const struct TALER_MERCHANT_RefundDetail) \
+  op (order_terms, const json_t) \
+  op (h_contract_terms, const struct TALER_PrivateContractHashP) \
+  op (h_wire, const struct TALER_MerchantWireHashP) \
+  op (proposal_reference, const char) \
+  op (template_description, const char) \
+  op (otp_device_description, const char) \
+  op (otp_id, const char) \
+  op (otp_key, const char) \
+  op (otp_alg, const enum TALER_MerchantConfirmationAlgorithm) \
+  op (template_id, const char) \
+  op (template_contract, const json_t) \
+  op (event_type, const char)   \
+  op (webhook_id, const char) \
+  op (merchant_base_url, const char) \
+  op (url, const char) \
+  op (http_method, const char)   \
+  op (header_template, const char)   \
+  op (body_template, const char)   \
+  op (summary, const char)   \
+  op (token_family_slug, const char)   \
+  op (token_family_duration, const struct GNUNET_TIME_Relative)   \
+  op (token_family_kind, const char)
 
 
 /**
@@ -2102,20 +2109,20 @@ TALER_TESTING_cmd_merchant_get_statisticsamount (const char *label,
  * @param op macro to call
  */
 #define TALER_MERCHANT_TESTING_INDEXED_TRAITS(op) \
-        op (coin_reference, const char) \
-        op (paths, const char) \
-        op (payto_uris, const struct TALER_FullPayto) \
-        op (h_wires, const struct TALER_MerchantWireHashP) \
-        op (amounts, const struct TALER_Amount)         \
-        op (urls, const char) \
-        op (http_methods, const char)   \
-        op (http_header, const char)   \
-        op (http_body, const void)   \
-        op (http_body_size, const size_t)   \
-        op (planchet_secrets, const struct TALER_PlanchetMasterSecretP)   \
-        op (token_priv, const struct TALER_TokenUsePrivateKeyP)   \
-        op (token_issue_sig, const struct TALER_TokenIssueSignature)   \
-        op (token_issue_pub, const struct TALER_TokenIssuePublicKey)
+  op (coin_reference, const char) \
+  op (paths, const char) \
+  op (payto_uris, const struct TALER_FullPayto) \
+  op (h_wires, const struct TALER_MerchantWireHashP) \
+  op (amounts, const struct TALER_Amount)         \
+  op (urls, const char) \
+  op (http_methods, const char)   \
+  op (http_header, const char)   \
+  op (http_body, const void)   \
+  op (http_body_size, const size_t)   \
+  op (planchet_secrets, const struct TALER_PlanchetMasterSecretP)   \
+  op (token_priv, const struct TALER_TokenUsePrivateKeyP)   \
+  op (token_issue_sig, const struct TALER_TokenIssueSignature)   \
+  op (token_issue_pub, const struct TALER_TokenIssuePublicKey)
 
 
 TALER_MERCHANT_TESTING_SIMPLE_TRAITS (TALER_TESTING_MAKE_DECL_SIMPLE_TRAIT)
