@@ -152,7 +152,7 @@ parse_intervals_and_buckets_amt (
       struct GNUNET_JSON_Specification spec[] = {
         GNUNET_JSON_spec_timestamp ("start_time",
                                     &jinterval->start_time),
-        GNUNET_JSON_spec_array_const ("cumulative_amount",
+        GNUNET_JSON_spec_array_const ("cumulative_amounts",
                                       &amounts_arr),
         GNUNET_JSON_spec_end ()
       };
@@ -205,7 +205,7 @@ parse_intervals_and_buckets_amt (
                                     &jbucket->end_time),
         GNUNET_JSON_spec_string ("range",
                                  &jbucket->range),
-        GNUNET_JSON_spec_array_const ("cumulative_amount",
+        GNUNET_JSON_spec_array_const ("cumulative_amounts",
                                       &amounts_arr),
         GNUNET_JSON_spec_end ()
       };
