@@ -136,18 +136,10 @@ handle_transfers_get_finished (void *cls,
                                      &td->exchange_url),
             GNUNET_JSON_spec_uint64 ("transfer_serial_id",
                                      &td->credit_serial),
-            GNUNET_JSON_spec_mark_optional (
-              GNUNET_JSON_spec_timestamp ("execution_time",
-                                          &td->execution_time),
-              NULL),
-            GNUNET_JSON_spec_mark_optional (
-              GNUNET_JSON_spec_bool ("verified",
-                                     &td->verified),
-              NULL),
-            GNUNET_JSON_spec_mark_optional (
-              GNUNET_JSON_spec_bool ("confirmed",
-                                     &td->confirmed),
-              NULL),
+            GNUNET_JSON_spec_timestamp ("execution_time",
+                                        &td->execution_time),
+            GNUNET_JSON_spec_bool ("expected",
+                                   &td->expected),
             GNUNET_JSON_spec_end ()
           };
 
@@ -224,13 +216,13 @@ TALER_MERCHANT_transfers_get (
   const struct GNUNET_TIME_Timestamp after,
   int64_t limit,
   uint64_t offset,
-  enum TALER_EXCHANGE_YesNoAll verified,
+  enum TALER_EXCHANGE_YesNoAll expected,
   TALER_MERCHANT_GetTransfersCallback cb,
   void *cb_cls)
 {
   struct TALER_MERCHANT_GetTransfersHandle *gth;
   CURL *eh;
-  const char *verified_s = NULL;
+  const char *expected_s = NULL;
   char limit_s[30];
   char offset_s[30];
   char before_s[30];
@@ -240,7 +232,7 @@ TALER_MERCHANT_transfers_get (
   gth->ctx = ctx;
   gth->cb = cb;
   gth->cb_cls = cb_cls;
-  verified_s = TALER_yna_to_string (verified);
+  expected_s = TALER_yna_to_string (expected);
   GNUNET_snprintf (limit_s,
                    sizeof (limit_s),
                    "%lld",
@@ -249,8 +241,6 @@ TALER_MERCHANT_transfers_get (
                    sizeof (offset_s),
                    "%lld",
                    (unsigned long long) offset);
-
-
   GNUNET_snprintf (before_s,
                    sizeof (before_s),
                    "%llu",
@@ -266,9 +256,9 @@ TALER_MERCHANT_transfers_get (
                                "private/transfers",
                                "payto_uri",
                                enc_payto,
-                               "verified",
-                               (TALER_EXCHANGE_YNA_ALL != verified)
-                               ? verified_s
+                               "expected",
+                               (TALER_EXCHANGE_YNA_ALL != expected)
+                               ? expected_s
                                : NULL,
                                "limit",
                                0 != limit
