@@ -185,7 +185,12 @@ TALER_MERCHANT_instance_patch (
     GNUNET_JSON_pack_time_rel ("default_pay_delay",
                                default_pay_delay),
     GNUNET_JSON_pack_time_rel ("default_refund_delay",
-                               default_refund_delay));
+                               default_refund_delay),
+    /* FIXME: add eventually to arguments when we transform the API... */
+    GNUNET_JSON_pack_time_rounder_interval (
+      "default_wire_transfer_rounding_interval",
+      GNUNET_TIME_RI_NONE)
+    );
   iph = GNUNET_new (struct TALER_MERCHANT_InstancePatchHandle);
   iph->ctx = ctx;
   iph->cb = cb;
