@@ -178,6 +178,10 @@ TALER_MERCHANT_product_patch (
   json_t *req_obj;
 
   req_obj = GNUNET_JSON_PACK (
+    /* FIXME: once we move to the new-style API,
+       allow applications to set the product name properly! */
+    GNUNET_JSON_pack_string ("product_name",
+                             description),
     GNUNET_JSON_pack_string ("description",
                              description),
     GNUNET_JSON_pack_object_incref ("description_i18n",
