@@ -162,8 +162,7 @@ TALER_MERCHANT_template_patch (
   const char *backend_url,
   const char *template_id,
   const char *template_description,
-  const char *pos_key,
-  enum TALER_MerchantConfirmationAlgorithm mca,
+  const char *otp_id,
   json_t *template_contract,
   TALER_MERCHANT_TemplatePatchCallback cb,
   void *cb_cls)
@@ -174,11 +173,9 @@ TALER_MERCHANT_template_patch (
   req_obj = GNUNET_JSON_PACK (
     GNUNET_JSON_pack_string ("template_description",
                              template_description),
-    GNUNET_JSON_pack_uint64 ("pos_algorithm",
-                             (uint32_t) mca),
     GNUNET_JSON_pack_allow_null (
-      GNUNET_JSON_pack_string ("pos_key",
-                               pos_key)),
+      GNUNET_JSON_pack_string ("otp_id",
+                               otp_id)),
     GNUNET_JSON_pack_object_incref ("template_contract",
                                     (json_t *) template_contract));
   tph = GNUNET_new (struct TALER_MERCHANT_TemplatePatchHandle);
