@@ -90,9 +90,9 @@ handle_paid_finished (void *cls,
 {
   struct TALER_MERCHANT_OrderPaidHandle *oph = cls;
   const json_t *json = response;
-  struct TALER_MERCHANT_HttpResponse hr = {
-    .http_status = (unsigned int) response_code,
-    .reply = json
+  struct TALER_MERCHANT_OrderPaidResponse opr = {
+    .hr.http_status = (unsigned int) response_code,
+    .hr.reply = json
   };
 
   oph->job = NULL;
@@ -102,61 +102,81 @@ handle_paid_finished (void *cls,
   switch (response_code)
   {
   case 0:
-    hr.ec = TALER_EC_GENERIC_INVALID_RESPONSE;
+    opr.hr.ec = TALER_EC_GENERIC_INVALID_RESPONSE;
     break;
-  case MHD_HTTP_NO_CONTENT:
+  case MHD_HTTP_OK:
+    {
+      bool refunded;
+      struct GNUNET_JSON_Specification spec[] = {
+        GNUNET_JSON_spec_bool ("refunded",
+                               &refunded),
+        GNUNET_JSON_spec_end ()
+      };
+
+      if (GNUNET_OK !=
+          GNUNET_JSON_parse (opr.hr.reply,
+                             spec,
+                             NULL,
+                             NULL))
+      {
+        GNUNET_break_op (0);
+        opr.hr.ec = TALER_EC_GENERIC_INVALID_RESPONSE;
+        break;
+      }
+      break;
+    }
     break;
   case MHD_HTTP_BAD_REQUEST:
-    hr.ec = TALER_JSON_get_error_code (json);
-    hr.hint = TALER_JSON_get_error_hint (json);
+    opr.hr.ec = TALER_JSON_get_error_code (json);
+    opr.hr.hint = TALER_JSON_get_error_hint (json);
     /* This should never happen, either us
      * or the merchant is buggy (or API version conflict);
      * just pass JSON reply to the application */
     break;
   case MHD_HTTP_FORBIDDEN:
-    hr.ec = TALER_JSON_get_error_code (json);
-    hr.hint = TALER_JSON_get_error_hint (json);
+    opr.hr.ec = TALER_JSON_get_error_code (json);
+    opr.hr.hint = TALER_JSON_get_error_hint (json);
     /* The signature provided was invalid */
     break;
   case MHD_HTTP_NOT_FOUND:
-    hr.ec = TALER_JSON_get_error_code (json);
-    hr.hint = TALER_JSON_get_error_hint (json);
+    opr.hr.ec = TALER_JSON_get_error_code (json);
+    opr.hr.hint = TALER_JSON_get_error_hint (json);
     /* Nothing really to verify, this should never
        happen, we should pass the JSON reply to the
        application */
     break;
   case MHD_HTTP_CONFLICT:
-    hr.ec = TALER_JSON_get_error_code (json);
-    hr.hint = TALER_JSON_get_error_hint (json);
+    opr.hr.ec = TALER_JSON_get_error_code (json);
+    opr.hr.hint = TALER_JSON_get_error_hint (json);
     /* The hashed contract terms don't match with the order_id. */
     break;
   case MHD_HTTP_INTERNAL_SERVER_ERROR:
-    hr.ec = TALER_JSON_get_error_code (json);
-    hr.hint = TALER_JSON_get_error_hint (json);
+    opr.hr.ec = TALER_JSON_get_error_code (json);
+    opr.hr.hint = TALER_JSON_get_error_hint (json);
     /* Server had an internal issue; we should retry,
        but this API leaves this to the application */
     break;
   case MHD_HTTP_SERVICE_UNAVAILABLE:
     TALER_MERCHANT_parse_error_details_ (json,
                                          response_code,
-                                         &hr);
+                                         &opr.hr);
     /* Exchange couldn't respond properly; the retry is
        left to the application */
     break;
   default:
     TALER_MERCHANT_parse_error_details_ (json,
                                          response_code,
-                                         &hr);
+                                         &opr.hr);
     /* unexpected response code */
     GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
                 "Unexpected response code %u/%d\n",
                 (unsigned int) response_code,
-                (int) hr.ec);
+                (int) opr.hr.ec);
     GNUNET_break_op (0);
     break;
   }
   oph->paid_cb (oph->paid_cb_cls,
-                &hr);
+                &opr);
   TALER_MERCHANT_order_paid_cancel (oph);
 }
 
@@ -168,6 +188,7 @@ TALER_MERCHANT_order_paid (
   const char *order_id,
   const char *session_id,
   const struct TALER_PrivateContractHashP *h_contract_terms,
+  const struct GNUNET_HashCode *wallet_data_hash,
   const struct TALER_MerchantSignatureP *merchant_sig,
   TALER_MERCHANT_OrderPaidCallback paid_cb,
   void *paid_cb_cls)
@@ -180,6 +201,9 @@ TALER_MERCHANT_order_paid (
                                 merchant_sig),
     GNUNET_JSON_pack_data_auto ("h_contract",
                                 h_contract_terms),
+    GNUNET_JSON_pack_allow_null (
+      GNUNET_JSON_pack_data_auto ("wallet_data_hash",
+                                  wallet_data_hash)),
     GNUNET_JSON_pack_string ("session_id",
                              session_id));
   oph = GNUNET_new (struct TALER_MERCHANT_OrderPaidHandle);
