@@ -84,8 +84,8 @@ struct TALER_MERCHANT_TokenFamiliesPostHandle
  */
 static void
 handle_post_token_families_finished (void *cls,
-                                    long response_code,
-                                    const void *response)
+                                     long response_code,
+                                     const void *response)
 {
   struct TALER_MERCHANT_TokenFamiliesPostHandle *handle = cls;
   const json_t *json = response;
@@ -98,7 +98,7 @@ handle_post_token_families_finished (void *cls,
   GNUNET_log (GNUNET_ERROR_TYPE_INFO,
               "POST /tokenfamilies completed with response code %u\n",
               (unsigned int) response_code);
-              switch (response_code)
+  switch (response_code)
   {
   case 0:
     hr.ec = TALER_EC_GENERIC_INVALID_RESPONSE;
@@ -158,6 +158,7 @@ handle_post_token_families_finished (void *cls,
   TALER_MERCHANT_token_families_post_cancel (handle);
 }
 
+
 struct TALER_MERCHANT_TokenFamiliesPostHandle *
 TALER_MERCHANT_token_families_post (
   struct GNUNET_CURL_Context *ctx,
@@ -166,10 +167,12 @@ TALER_MERCHANT_token_families_post (
   const char *name,
   const char *description,
   const json_t *description_i18n,
+  const json_t *extra_data,
   struct GNUNET_TIME_Timestamp valid_after,
   struct GNUNET_TIME_Timestamp valid_before,
   struct GNUNET_TIME_Relative duration,
-  struct GNUNET_TIME_Relative rounding,
+  struct GNUNET_TIME_Relative validity_granularity,
+  struct GNUNET_TIME_Relative start_offset,
   const char *kind,
   TALER_MERCHANT_TokenFamiliesPostCallback cb,
   void *cb_cls)
@@ -187,6 +190,9 @@ TALER_MERCHANT_token_families_post (
     GNUNET_JSON_pack_allow_null (
       GNUNET_JSON_pack_object_incref ("description_i18n",
                                       (json_t *) description_i18n)),
+    GNUNET_JSON_pack_allow_null (
+      GNUNET_JSON_pack_object_incref ("extra_data",
+                                      (json_t *) extra_data)),
     GNUNET_JSON_pack_allow_null (
       GNUNET_JSON_pack_timestamp ("valid_after",
                                   valid_after)),
@@ -194,8 +200,10 @@ TALER_MERCHANT_token_families_post (
                                 valid_before),
     GNUNET_JSON_pack_time_rel ("duration",
                                duration),
-    GNUNET_JSON_pack_time_rel ("rounding",
-                               rounding),
+    GNUNET_JSON_pack_time_rel ("validity_granularity",
+                               validity_granularity),
+    GNUNET_JSON_pack_time_rel ("start_offset",
+                               start_offset),
     GNUNET_JSON_pack_string ("kind",
                              kind));
   handle = GNUNET_new (struct TALER_MERCHANT_TokenFamiliesPostHandle);
