@@ -97,7 +97,7 @@ echo -n "Configuring merchant instance ..."
 STATUS=$(curl -H "Content-Type: application/json" -X POST \
     -H 'Authorization: Bearer secret-token:super_secret' \
     http://localhost:9966/management/instances \
-    -d '{"auth":{"method":"external"},"id":"default","name":"default","user_type":"business","address":{},"jurisdiction":{},"use_stefan":true,"default_wire_transfer_delay":{"d_us" : 50000000000},"default_pay_delay":{"d_us": 60000000000}}' \
+    -d '{"auth":{"method":"external"},"id":"admin","name":"default","user_type":"business","address":{},"jurisdiction":{},"use_stefan":true,"default_wire_transfer_delay":{"d_us" : 50000000000},"default_pay_delay":{"d_us": 60000000000}}' \
     -w "%{http_code}" -s -o /dev/null)
 
 if [ "$STATUS" != "204" ]
@@ -482,8 +482,15 @@ echo "OK"
 NOW=$(date +%s)
 
 echo -n "Pay first order ${PAY_URL} ..."
-taler-wallet-cli --no-throttle --wallet-db="$WALLET_DB" handle-uri "${PAY_URL}" -y 2> wallet-pay1.err > wallet-pay1.log
-taler-wallet-cli --no-throttle --wallet-db="$WALLET_DB" run-until-done 2> wallet-finish-pay1.err > wallet-finish-pay1.log
+taler-wallet-cli \
+    --no-throttle \
+    --wallet-db="$WALLET_DB" \
+    handle-uri "${PAY_URL}" \
+    -y 2> wallet-pay1.err > wallet-pay1.log
+taler-wallet-cli \
+    --no-throttle \
+    --wallet-db="$WALLET_DB" \
+    run-until-done 2> wallet-finish-pay1.err > wallet-finish-pay1.log
 NOW2=$(date +%s)
 echo " OK (took $(( NOW2 - NOW )) secs )"
 
@@ -513,12 +520,20 @@ WIRE_DEADLINE=$(jq -r .contract_terms.wire_transfer_deadline.t_s < "$LAST_RESPON
 
 NOW=$(date +%s)
 
-TO_SLEEP=$(( WIRE_DEADLINE - NOW ))
+TO_SLEEP=$((1200 + WIRE_DEADLINE - NOW ))
 echo "Waiting $TO_SLEEP secs for wire transfer"
 
 echo -n "Perform wire transfers ..."
-taler-exchange-aggregator -y -c "$CONF" -T "${TO_SLEEP}"000000 -t -L INFO &> aggregator.log
-taler-exchange-transfer -c "$CONF" -t -L INFO &> transfer.log
+taler-exchange-aggregator \
+    -y \
+    -c "$CONF" \
+    -T "${TO_SLEEP}"000000 \
+    -t \
+    -L INFO &> aggregator.log
+taler-exchange-transfer \
+    -c "$CONF" \
+    -t \
+    -L INFO &> transfer.log
 echo " DONE"
 echo -n "Give time to Nexus to route the payment to Sandbox..."
 # FIXME-MS: trigger immediate update at nexus
@@ -560,21 +575,6 @@ fi
 
 echo "OK"
 
-echo -n "Notifying merchant of correct wire transfer (conflicting with old data)..."
-
-STATUS=$(curl 'http://localhost:9966/private/transfers' \
-    -d '{"credit_amount":"'"$CREDIT_AMOUNT"'","wtid":"'"$WTID"'","payto_uri":"'"$TARGET_PAYTO"'","exchange_url":"'"$WURL"'"}' \
-    -m 3 \
-    -w "%{http_code}" -s -o "$LAST_RESPONSE")
-
-if [ "$STATUS" != "409" ]
-then
-    jq . < "$LAST_RESPONSE"
-    exit_fail "Expected response conflict, after providing conflicting transfer data. got: $STATUS"
-fi
-
-echo " OK"
-
 echo -n "Deleting bogus wire transfer ..."
 
 TID=$(curl -s http://localhost:9966/private/transfers | jq -r .transfers[0].transfer_serial_id)
@@ -599,7 +599,7 @@ fi
 
 echo " OK"
 
-echo -n "Notifying merchant of correct wire transfer (now working)..."
+echo -n "Notifying merchant of correct wire transfer..."
 
 STATUS=$(curl 'http://localhost:9966/private/transfers' \
     -d '{"credit_amount":"'"$CREDIT_AMOUNT"'","wtid":"'"$WTID"'","payto_uri":"'"$TARGET_PAYTO"'","exchange_url":"'"$WURL"'"}' \
@@ -614,26 +614,22 @@ fi
 
 echo " OK"
 
-echo -n "Testing idempotence ..."
+echo -n "Running taler-merchant-depositcheck ..."
 set -e
-
-
-# Test idempotence: do it again!
-
-STATUS=$(curl 'http://localhost:9966/private/transfers' \
-    -d '{"credit_amount":"'"$CREDIT_AMOUNT"'","wtid":"'"$WTID"'","payto_uri":"'"$TARGET_PAYTO"'","exchange_url":"'"$WURL"'"}' \
-    -w "%{http_code}" -s -o "$LAST_RESPONSE")
-
-if [ "$STATUS" != "204" ]
-then
-    jq . < "$LAST_RESPONSE"
-    exit_fail "Expected response No Content, after providing transfer data. got: $STATUS"
-fi
-
+taler-merchant-depositcheck \
+    -L INFO \
+    -c "$CONF" \
+    -T "${TO_SLEEP}"000000 \
+    -t &> taler-merchant-depositcheck.log
 echo " OK"
-echo -n "Testing taler-merchant-reconciliation ..."
+
+echo -n "Running taler-merchant-reconciliation ..."
 set -e
-taler-merchant-reconciliation -L INFO -c "$CONF" -t &> taler-merchant-reconciliation.log
+taler-merchant-reconciliation \
+    -L INFO \
+    -c "$CONF" \
+    -T "${TO_SLEEP}"000000 \
+    -t &> taler-merchant-reconciliation.log
 echo " OK"
 
 
