@@ -295,6 +295,24 @@ then
     cat "$LAST_RESPONSE"
     exit_fail "Expected 204, updating product. got: $STATUS"
 fi
+
+echo -n "Requesting inventory..."
+STATUS=$(curl 'http://localhost:9966/private/products?name_filter=more' \
+    -w "%{http_code}" -s -o "$LAST_RESPONSE")
+
+if [ "$STATUS" != "200" ]
+then
+    cat "$LAST_RESPONSE"
+    exit_fail "Expected 200. got: $STATUS"
+fi
+
+PRODUCT_COUNT=$(jq -r '.products|length' < "$LAST_RESPONSE")
+
+if [ "$PRODUCT_COUNT" != "1" ]
+then
+    cat "$LAST_RESPONSE"
+    exit_fail "Expected one product for the 'more'. filter, got: $PRODUCT_COUNT"
+fi
 echo " OK"
 
 exit 0
