@@ -60,9 +60,9 @@ struct PatchTemplateState
   const char *template_description;
 
   /**
-   * base64-encoded key
+   * OTP device ID
    */
-  char *pos_key;
+  char *otp_id;
 
   /**
    * Contract of the company
@@ -137,15 +137,15 @@ patch_template_run (void *cls,
   struct PatchTemplateState *pis = cls;
 
   pis->is = is;
-  pis->iph = TALER_MERCHANT_template_patch (is->ctx,
-                                            pis->merchant_url,
-                                            pis->template_id,
-                                            pis->template_description,
-                                            pis->pos_key,
-                                            TALER_MCA_NONE,
-                                            pis->template_contract,
-                                            &patch_template_cb,
-                                            pis);
+  pis->iph = TALER_MERCHANT_template_patch (
+    TALER_TESTING_interpreter_get_context (is),
+    pis->merchant_url,
+    pis->template_id,
+    pis->template_description,
+    pis->otp_id,
+    pis->template_contract,
+    &patch_template_cb,
+    pis);
   GNUNET_assert (NULL != pis->iph);
 }
 
@@ -168,11 +168,10 @@ patch_template_traits (void *cls,
 {
   struct PatchTemplateState *pts = cls;
   struct TALER_TESTING_Trait traits[] = {
-    TALER_TESTING_make_trait_template_description (&pts->template_description),
-    TALER_TESTING_make_trait_template_pos_key (
-      (const char **) &pts->pos_key),
+    TALER_TESTING_make_trait_template_description (pts->template_description),
+    TALER_TESTING_make_trait_otp_id (pts->otp_id),
     TALER_TESTING_make_trait_template_contract (pts->template_contract),
-    TALER_TESTING_make_trait_template_id (&pts->template_id),
+    TALER_TESTING_make_trait_template_id (pts->template_id),
     TALER_TESTING_trait_end (),
   };
 
@@ -202,7 +201,7 @@ patch_template_cleanup (void *cls,
                 "PATCH /templates/$ID operation did not complete\n");
     TALER_MERCHANT_template_patch_cancel (pis->iph);
   }
-  GNUNET_free (pis->pos_key);
+  GNUNET_free (pis->otp_id);
   json_decref (pis->template_contract);
   GNUNET_free (pis);
 }
@@ -214,7 +213,7 @@ TALER_TESTING_cmd_merchant_patch_template (
   const char *merchant_url,
   const char *template_id,
   const char *template_description,
-  const char *pos_key,
+  const char *otp_id,
   json_t *template_contract,
   unsigned int http_status)
 {
@@ -225,7 +224,7 @@ TALER_TESTING_cmd_merchant_patch_template (
   pis->template_id = template_id;
   pis->http_status = http_status;
   pis->template_description = template_description;
-  pis->pos_key = (NULL == pos_key) ? NULL : GNUNET_strdup (pos_key);
+  pis->otp_id = (NULL == otp_id) ? NULL : GNUNET_strdup (otp_id);
   pis->template_contract = template_contract; /* ownership taken */
   {
     struct TALER_TESTING_Command cmd = {
