@@ -303,7 +303,8 @@ TALER_TESTING_cmd_merchant_post_instances (
     json_pack ("{s:s}", "city", "lawyercity"),
     true,
     GNUNET_TIME_UNIT_ZERO, /* no wire transfer delay */
-    GNUNET_TIME_UNIT_MINUTES,
+    GNUNET_TIME_relative_multiply (GNUNET_TIME_UNIT_SECONDS,
+                                   2), /* small pay delay */
     NULL,
     http_status);
 }
