@@ -145,6 +145,7 @@ post_tokenfamilies_cb (void *cls,
   TALER_TESTING_interpreter_next (state->is);
 }
 
+
 /**
  * Run the "POST /tokenfamilies" CMD.
  *
@@ -168,16 +169,19 @@ post_tokenfamilies_run (void *cls,
     state->name,
     state->description,
     state->description_i18n,
+    NULL, /* extra data */
     state->valid_after,
     state->valid_before,
     state->duration,
     state->rounding,
+    GNUNET_TIME_UNIT_ZERO, /* start_offset */
     state->kind,
     &post_tokenfamilies_cb,
     state);
   GNUNET_assert (NULL != state->handle);
 }
 
+
 /**
  * Offers information from the "POST /tokenfamilies" CMD state to other
  * commands.
@@ -212,6 +216,7 @@ post_tokenfamilies_traits (void *cls,
                                   index);
 }
 
+
 /**
  * Free the state of a "POST /tokenfamilies" CMD, and possibly
  * cancel a pending operation thereof.
@@ -235,6 +240,7 @@ post_tokenfamilies_cleanup (void *cls,
   GNUNET_free (state);
 }
 
+
 struct TALER_TESTING_Command
 TALER_TESTING_cmd_merchant_post_tokenfamilies (
   const char *label,
@@ -277,4 +283,4 @@ TALER_TESTING_cmd_merchant_post_tokenfamilies (
 
     return cmd;
   }
-}
\ No newline at end of file
+}
